

whitespace tweaks for filesystem option parsing patch



 fs/adfs/super.c    |   32 ++--
 fs/affs/super.c    |  114 ++++++++--------
 fs/autofs/inode.c  |   40 ++---
 fs/autofs4/inode.c |   40 ++---
 fs/ext2/super.c    |  154 +++++++++++-----------
 fs/ext3/super.c    |  268 +++++++++++++++++++--------------------
 fs/fat/inode.c     |  360 ++++++++++++++++++++++++++---------------------------
 fs/hfs/super.c     |  172 ++++++++++++-------------
 fs/hpfs/super.c    |  152 +++++++++++-----------
 fs/isofs/inode.c   |  132 +++++++++----------
 fs/jfs/super.c     |   70 +++++-----
 fs/proc/inode.c    |   16 +-
 fs/udf/super.c     |  138 ++++++++++----------
 fs/ufs/super.c     |  108 +++++++--------
 lib/parser.c       |   42 +++---
 15 files changed, 919 insertions(+), 919 deletions(-)

diff -puN fs/adfs/super.c~filesystem-option-parsing-tweaks fs/adfs/super.c
--- 25/fs/adfs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/adfs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -160,22 +160,22 @@ static int parse_options(struct super_bl
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_uid:
-				asb->s_uid = match_int(args);
-				break;
-			case Opt_gid:
-				asb->s_gid = match_int(args);
-				break;
-			case Opt_ownmask:
-				asb->s_owner_mask = match_octal(args);
-				break;
-			case Opt_othmask:
-				asb->s_other_mask = match_octal(args);
-				break;
-			default:
-				printk("ADFS-fs: unrecognised mount option \"%s\" "
-						"or missing value\n", p);
-				return -EINVAL;
+		case Opt_uid:
+			asb->s_uid = match_int(args);
+			break;
+		case Opt_gid:
+			asb->s_gid = match_int(args);
+			break;
+		case Opt_ownmask:
+			asb->s_owner_mask = match_octal(args);
+			break;
+		case Opt_othmask:
+			asb->s_other_mask = match_octal(args);
+			break;
+		default:
+			printk("ADFS-fs: unrecognised mount option \"%s\" "
+					"or missing value\n", p);
+			return -EINVAL;
 		}
 	}
 	return 0;
diff -puN fs/affs/super.c~filesystem-option-parsing-tweaks fs/affs/super.c
--- 25/fs/affs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/affs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -195,65 +195,65 @@ parse_options(char *options, uid_t *uid,
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_bs:
-				n = match_int(&args[0]);
-				if (n != 512 && n != 1024 && n != 2048
-				    && n != 4096) {
-					printk ("AFFS: Invalid blocksize (512, 1024, 2048, 4096 allowed)\n");
-					return 0;
-				}
-				*blocksize = n;
-				break;
-			case Opt_mode:
-				*mode = match_octal(&args[0]) & 0777;
-				*mount_opts |= SF_SETMODE;
-				break;
-			case Opt_mufs:
-				*mount_opts |= SF_MUFS;
-				break;
-			case Opt_prefix:
-				if (*prefix) {		/* Free any previous prefix */
-					kfree(*prefix);
-					*prefix = NULL;
-				}
-				*prefix = match_strdup(&args[0]);
-				if (!*prefix)
-					return 0;
-				*mount_opts |= SF_PREFIX;
-				break;
-			case Opt_protect:
-				*mount_opts |= SF_IMMUTABLE;
-				break;
-			case Opt_reserved:
-				*reserved = match_int(&args[0]);
-				break;
-			case Opt_root:
-				*root = match_int(&args[0]);
-				break;
-			case Opt_setgid:
-				*gid = match_int(&args[0]);
-				*mount_opts |= SF_SETGID;
-				break;
-			case Opt_setuid:
-				*uid = match_int(&args[0]);
-				*mount_opts |= SF_SETUID;
-				break;
-			case Opt_verbose:
-				*mount_opts |= SF_VERBOSE;
-				break;
-			case Opt_volume: {
-				char *vol = match_strdup(&args[0]);
-				strlcpy(volume, vol, 32);
-				kfree(vol);
-				break;
+		case Opt_bs:
+			n = match_int(&args[0]);
+			if (n != 512 && n != 1024 && n != 2048
+			    && n != 4096) {
+				printk ("AFFS: Invalid blocksize (512, 1024, 2048, 4096 allowed)\n");
+				return 0;
+			}
+			*blocksize = n;
+			break;
+		case Opt_mode:
+			*mode = match_octal(&args[0]) & 0777;
+			*mount_opts |= SF_SETMODE;
+			break;
+		case Opt_mufs:
+			*mount_opts |= SF_MUFS;
+			break;
+		case Opt_prefix:
+			if (*prefix) {		/* Free any previous prefix */
+				kfree(*prefix);
+				*prefix = NULL;
 			}
-			case Opt_ignore:
-			 	/* Silently ignore the quota options */
-				break;
-			default:
-				printk("AFFS: Unrecognized mount option \"%s\" "
-						"or missing value\n", p);
+			*prefix = match_strdup(&args[0]);
+			if (!*prefix)
 				return 0;
+			*mount_opts |= SF_PREFIX;
+			break;
+		case Opt_protect:
+			*mount_opts |= SF_IMMUTABLE;
+			break;
+		case Opt_reserved:
+			*reserved = match_int(&args[0]);
+			break;
+		case Opt_root:
+			*root = match_int(&args[0]);
+			break;
+		case Opt_setgid:
+			*gid = match_int(&args[0]);
+			*mount_opts |= SF_SETGID;
+			break;
+		case Opt_setuid:
+			*uid = match_int(&args[0]);
+			*mount_opts |= SF_SETUID;
+			break;
+		case Opt_verbose:
+			*mount_opts |= SF_VERBOSE;
+			break;
+		case Opt_volume: {
+			char *vol = match_strdup(&args[0]);
+			strlcpy(volume, vol, 32);
+			kfree(vol);
+			break;
+		}
+		case Opt_ignore:
+		 	/* Silently ignore the quota options */
+			break;
+		default:
+			printk("AFFS: Unrecognized mount option \"%s\" "
+					"or missing value\n", p);
+			return 0;
 		}
 	}
 	return 1;
diff -puN fs/autofs4/inode.c~filesystem-option-parsing-tweaks fs/autofs4/inode.c
--- 25/fs/autofs4/inode.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/autofs4/inode.c	2003-09-26 22:20:16.000000000 -0700
@@ -132,26 +132,26 @@ static int parse_options(char *options, 
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_fd:
-				*pipefd = match_int(args);
-				break;
-			case Opt_uid:
-				*uid = match_int(args);
-				break;
-			case Opt_gid:
-				*gid = match_int(args);
-				break;
-			case Opt_pgrp:
-				*pgrp = match_int(args);
-				break;
-			case Opt_minproto:
-				*minproto = match_int(args);
-				break;
-			case Opt_maxproto:
-				*maxproto = match_int(args);
-				break;
-			default:
-				return 1;
+		case Opt_fd:
+			*pipefd = match_int(args);
+			break;
+		case Opt_uid:
+			*uid = match_int(args);
+			break;
+		case Opt_gid:
+			*gid = match_int(args);
+			break;
+		case Opt_pgrp:
+			*pgrp = match_int(args);
+			break;
+		case Opt_minproto:
+			*minproto = match_int(args);
+			break;
+		case Opt_maxproto:
+			*maxproto = match_int(args);
+			break;
+		default:
+			return 1;
 		}
 	}
 	return (*pipefd < 0);
diff -puN fs/autofs/inode.c~filesystem-option-parsing-tweaks fs/autofs/inode.c
--- 25/fs/autofs/inode.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/autofs/inode.c	2003-09-26 22:20:16.000000000 -0700
@@ -81,26 +81,26 @@ static int parse_options(char *options, 
 
 		token = match_token(p, autofs_tokens, args);
 		switch (token) {
-			case Opt_fd:
-				*pipefd = match_int(&args[0]);
-				break;
-			case Opt_uid:
-				*uid = match_int(&args[0]);
-				break;
-			case Opt_gid:
-				*gid = match_int(&args[0]);
-				break;
-			case Opt_pgrp:
-				*pgrp = match_int(&args[0]);
-				break;
-			case Opt_minproto:
-				*minproto = match_int(&args[0]);
-				break;
-			case Opt_maxproto:
-				*maxproto = match_int(&args[0]);
-				break;
-			default:
-				return 1;
+		case Opt_fd:
+			*pipefd = match_int(&args[0]);
+			break;
+		case Opt_uid:
+			*uid = match_int(&args[0]);
+			break;
+		case Opt_gid:
+			*gid = match_int(&args[0]);
+			break;
+		case Opt_pgrp:
+			*pgrp = match_int(&args[0]);
+			break;
+		case Opt_minproto:
+			*minproto = match_int(&args[0]);
+			break;
+		case Opt_maxproto:
+			*maxproto = match_int(&args[0]);
+			break;
+		default:
+			return 1;
 		}
 	}
 	return (*pipefd < 0);
diff -puN fs/ext2/super.c~filesystem-option-parsing-tweaks fs/ext2/super.c
--- 25/fs/ext2/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/ext2/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -323,92 +323,92 @@ static int parse_options (char * options
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_bsd_df:
-				clear_opt (sbi->s_mount_opt, MINIX_DF);
-				break;
-			case Opt_minix_df:
-				set_opt (sbi->s_mount_opt, MINIX_DF);
-				break;
-			case Opt_grpid:
-				set_opt (sbi->s_mount_opt, GRPID);
-				break;
-			case Opt_nogrpid:
-				clear_opt (sbi->s_mount_opt, GRPID);
-				break;
-			case Opt_resuid:
-				sbi->s_resuid = match_int(&args[0]);
-				break;
-			case Opt_resgid:
-				sbi->s_resgid = match_int(&args[0]);
-				break;
-			case Opt_sb:
-				/* handled by get_sb_block() instead of here */
-				/* *sb_block = match_int(&args[0]); */
-				break;
-			case Opt_err_panic:
-				kind = EXT2_MOUNT_ERRORS_PANIC;
-				break;
-			case Opt_err_ro:
-				kind = EXT2_MOUNT_ERRORS_RO;
-				break;
-			case Opt_err_cont:
-				kind = EXT2_MOUNT_ERRORS_CONT;
-				break;
-			case Opt_nouid32:
-				set_opt (sbi->s_mount_opt, NO_UID32);
-				break;
-			case Opt_check:
+		case Opt_bsd_df:
+			clear_opt (sbi->s_mount_opt, MINIX_DF);
+			break;
+		case Opt_minix_df:
+			set_opt (sbi->s_mount_opt, MINIX_DF);
+			break;
+		case Opt_grpid:
+			set_opt (sbi->s_mount_opt, GRPID);
+			break;
+		case Opt_nogrpid:
+			clear_opt (sbi->s_mount_opt, GRPID);
+			break;
+		case Opt_resuid:
+			sbi->s_resuid = match_int(&args[0]);
+			break;
+		case Opt_resgid:
+			sbi->s_resgid = match_int(&args[0]);
+			break;
+		case Opt_sb:
+			/* handled by get_sb_block() instead of here */
+			/* *sb_block = match_int(&args[0]); */
+			break;
+		case Opt_err_panic:
+			kind = EXT2_MOUNT_ERRORS_PANIC;
+			break;
+		case Opt_err_ro:
+			kind = EXT2_MOUNT_ERRORS_RO;
+			break;
+		case Opt_err_cont:
+			kind = EXT2_MOUNT_ERRORS_CONT;
+			break;
+		case Opt_nouid32:
+			set_opt (sbi->s_mount_opt, NO_UID32);
+			break;
+		case Opt_check:
 #ifdef CONFIG_EXT2_CHECK
-				set_opt (sbi->s_mount_opt, CHECK);
+			set_opt (sbi->s_mount_opt, CHECK);
 #else
-				printk("EXT2 Check option not supported\n");
+			printk("EXT2 Check option not supported\n");
 #endif
-				break;
-			case Opt_nocheck:
-				clear_opt (sbi->s_mount_opt, CHECK);
-				break;
-			case Opt_debug:
-				set_opt (sbi->s_mount_opt, DEBUG);
-				break;
-			case Opt_oldalloc:
-				set_opt (sbi->s_mount_opt, OLDALLOC);
-				break;
-			case Opt_orlov:
-				clear_opt (sbi->s_mount_opt, OLDALLOC);
-				break;
-			case Opt_nobh:
-				set_opt (sbi->s_mount_opt, NOBH);
-				break;
+			break;
+		case Opt_nocheck:
+			clear_opt (sbi->s_mount_opt, CHECK);
+			break;
+		case Opt_debug:
+			set_opt (sbi->s_mount_opt, DEBUG);
+			break;
+		case Opt_oldalloc:
+			set_opt (sbi->s_mount_opt, OLDALLOC);
+			break;
+		case Opt_orlov:
+			clear_opt (sbi->s_mount_opt, OLDALLOC);
+			break;
+		case Opt_nobh:
+			set_opt (sbi->s_mount_opt, NOBH);
+			break;
 #ifdef CONFIG_EXT2_FS_XATTR
-			case Opt_user_xattr:
-				set_opt (sbi->s_mount_opt, XATTR_USER);
-				break;
-			case Opt_nouser_xattr:
-				clear_opt (sbi->s_mount_opt, XATTR_USER);
-				break;
+		case Opt_user_xattr:
+			set_opt (sbi->s_mount_opt, XATTR_USER);
+			break;
+		case Opt_nouser_xattr:
+			clear_opt (sbi->s_mount_opt, XATTR_USER);
+			break;
 #else
-			case Opt_user_xattr:
-			case Opt_nouser_xattr:
-				printk("EXT2 (no)user_xattr options not supported\n");
-				break;
+		case Opt_user_xattr:
+		case Opt_nouser_xattr:
+			printk("EXT2 (no)user_xattr options not supported\n");
+			break;
 #endif
 #ifdef CONFIG_EXT2_FS_POSIX_ACL
-			case Opt_acl:
-				set_opt(sbi->s_mount_opt, POSIX_ACL);
-				break;
-			case Opt_noacl:
-				clear_opt(sbi->s_mount_opt, POSIX_ACL);
-				break;
+		case Opt_acl:
+			set_opt(sbi->s_mount_opt, POSIX_ACL);
+			break;
+		case Opt_noacl:
+			clear_opt(sbi->s_mount_opt, POSIX_ACL);
+			break;
 #else
-			case Opt_acl:
-			case Opt_noacl:
-				printk("EXT2 (no)acl options not supported\n");
-				break;
+		case Opt_acl:
+		case Opt_noacl:
+			printk("EXT2 (no)acl options not supported\n");
+			break;
 #endif
-			case Opt_ignore:
-				break;
-			default:
-				return 0;
+		case Opt_ignore:
+			break;
+		default:
+			return 0;
 		}
 	}
 	sbi->s_mount_opt |= kind;
diff -puN fs/ext3/super.c~filesystem-option-parsing-tweaks fs/ext3/super.c
--- 25/fs/ext3/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/ext3/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -613,151 +613,151 @@ static int parse_options (char * options
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_bsd_df:
-				clear_opt (sbi->s_mount_opt, MINIX_DF);
-				break;
-			case Opt_minix_df:
-				set_opt (sbi->s_mount_opt, MINIX_DF);
-				break;
-			case Opt_grpid:
-				set_opt (sbi->s_mount_opt, GRPID);
-				break;
-			case Opt_nogrpid:
-				clear_opt (sbi->s_mount_opt, GRPID);
-				break;
-			case Opt_resuid:
-				sbi->s_resuid = match_int(&args[0]);
-				break;
-			case Opt_resgid:
-				sbi->s_resgid = match_int(&args[0]);
-				break;
-			case Opt_sb:
-				/* handled by get_sb_block() instead of here */
-				/* *sb_block = match_int(&args[0]); */
-				break;
-			case Opt_err_panic:
-				clear_opt (sbi->s_mount_opt, ERRORS_CONT);
-				clear_opt (sbi->s_mount_opt, ERRORS_RO);
-				set_opt (sbi->s_mount_opt, ERRORS_PANIC);
-				break;
-			case Opt_err_ro:
-				clear_opt (sbi->s_mount_opt, ERRORS_CONT);
-				clear_opt (sbi->s_mount_opt, ERRORS_PANIC);
-				set_opt (sbi->s_mount_opt, ERRORS_RO);
-				break;
-			case Opt_err_cont:
-				clear_opt (sbi->s_mount_opt, ERRORS_RO);
-				clear_opt (sbi->s_mount_opt, ERRORS_PANIC);
-				set_opt (sbi->s_mount_opt, ERRORS_CONT);
-				break;
-			case Opt_nouid32:
-				set_opt (sbi->s_mount_opt, NO_UID32);
-				break;
-			case Opt_check:
+		case Opt_bsd_df:
+			clear_opt (sbi->s_mount_opt, MINIX_DF);
+			break;
+		case Opt_minix_df:
+			set_opt (sbi->s_mount_opt, MINIX_DF);
+			break;
+		case Opt_grpid:
+			set_opt (sbi->s_mount_opt, GRPID);
+			break;
+		case Opt_nogrpid:
+			clear_opt (sbi->s_mount_opt, GRPID);
+			break;
+		case Opt_resuid:
+			sbi->s_resuid = match_int(&args[0]);
+			break;
+		case Opt_resgid:
+			sbi->s_resgid = match_int(&args[0]);
+			break;
+		case Opt_sb:
+			/* handled by get_sb_block() instead of here */
+			/* *sb_block = match_int(&args[0]); */
+			break;
+		case Opt_err_panic:
+			clear_opt (sbi->s_mount_opt, ERRORS_CONT);
+			clear_opt (sbi->s_mount_opt, ERRORS_RO);
+			set_opt (sbi->s_mount_opt, ERRORS_PANIC);
+			break;
+		case Opt_err_ro:
+			clear_opt (sbi->s_mount_opt, ERRORS_CONT);
+			clear_opt (sbi->s_mount_opt, ERRORS_PANIC);
+			set_opt (sbi->s_mount_opt, ERRORS_RO);
+			break;
+		case Opt_err_cont:
+			clear_opt (sbi->s_mount_opt, ERRORS_RO);
+			clear_opt (sbi->s_mount_opt, ERRORS_PANIC);
+			set_opt (sbi->s_mount_opt, ERRORS_CONT);
+			break;
+		case Opt_nouid32:
+			set_opt (sbi->s_mount_opt, NO_UID32);
+			break;
+		case Opt_check:
 #ifdef CONFIG_EXT3_CHECK
-				set_opt (sbi->s_mount_opt, CHECK);
+			set_opt (sbi->s_mount_opt, CHECK);
 #else
-				printk(KERN_ERR 
-				       "EXT3 Check option not supported\n");
+			printk(KERN_ERR
+			       "EXT3 Check option not supported\n");
 #endif
-				break;
-			case Opt_nocheck:
-				clear_opt (sbi->s_mount_opt, CHECK);
-				break;
-			case Opt_debug:
-				set_opt (sbi->s_mount_opt, DEBUG);
-				break;
-			case Opt_oldalloc:
-				set_opt (sbi->s_mount_opt, OLDALLOC);
-				break;
-			case Opt_orlov:
-				clear_opt (sbi->s_mount_opt, OLDALLOC);
-				break;
+			break;
+		case Opt_nocheck:
+			clear_opt (sbi->s_mount_opt, CHECK);
+			break;
+		case Opt_debug:
+			set_opt (sbi->s_mount_opt, DEBUG);
+			break;
+		case Opt_oldalloc:
+			set_opt (sbi->s_mount_opt, OLDALLOC);
+			break;
+		case Opt_orlov:
+			clear_opt (sbi->s_mount_opt, OLDALLOC);
+			break;
 #ifdef CONFIG_EXT3_FS_XATTR
-			case Opt_user_xattr:
-				set_opt (sbi->s_mount_opt, XATTR_USER);
-				break;
-			case Opt_nouser_xattr:
-				clear_opt (sbi->s_mount_opt, XATTR_USER);
-				break;
+		case Opt_user_xattr:
+			set_opt (sbi->s_mount_opt, XATTR_USER);
+			break;
+		case Opt_nouser_xattr:
+			clear_opt (sbi->s_mount_opt, XATTR_USER);
+			break;
 #else
-			case Opt_user_xattr:
-			case Opt_nouser_xattr:
-				printk("EXT3 (no)user_xattr options not supported\n");
-				break;
+		case Opt_user_xattr:
+		case Opt_nouser_xattr:
+			printk("EXT3 (no)user_xattr options not supported\n");
+			break;
 #endif
 #ifdef CONFIG_EXT3_FS_POSIX_ACL
-			case Opt_acl:
-				set_opt(sbi->s_mount_opt, POSIX_ACL);
-				break;
-			case Opt_noacl:
-				clear_opt(sbi->s_mount_opt, POSIX_ACL);
-				break;
+		case Opt_acl:
+			set_opt(sbi->s_mount_opt, POSIX_ACL);
+			break;
+		case Opt_noacl:
+			clear_opt(sbi->s_mount_opt, POSIX_ACL);
+			break;
 #else
-			case Opt_acl:
-			case Opt_noacl:
-				printk("EXT3 (no)acl options not supported\n");
-				break;
+		case Opt_acl:
+		case Opt_noacl:
+			printk("EXT3 (no)acl options not supported\n");
+			break;
 #endif
-			case Opt_journal_update:
-				/* @@@ FIXME */
-				/* Eventually we will want to be able to create
-				   a journal file here.  For now, only allow the
-				   user to specify an existing inode to be the
-				   journal file. */
-				if (is_remount) {
-					printk(KERN_ERR "EXT3-fs: cannot specify "
-					       "journal on remount\n");
-					return 0;
-				}
-				set_opt (sbi->s_mount_opt, UPDATE_JOURNAL);
-				break;
-			case Opt_journal_inum:
-				if (is_remount) {
-					printk(KERN_ERR "EXT3-fs: cannot specify "
-					       "journal on remount\n");
+		case Opt_journal_update:
+			/* @@@ FIXME */
+			/* Eventually we will want to be able to create
+			   a journal file here.  For now, only allow the
+			   user to specify an existing inode to be the
+			   journal file. */
+			if (is_remount) {
+				printk(KERN_ERR "EXT3-fs: cannot specify "
+				       "journal on remount\n");
+				return 0;
+			}
+			set_opt (sbi->s_mount_opt, UPDATE_JOURNAL);
+			break;
+		case Opt_journal_inum:
+			if (is_remount) {
+				printk(KERN_ERR "EXT3-fs: cannot specify "
+				       "journal on remount\n");
+				return 0;
+			}
+			*inum = match_int(&args[0]);
+			break;
+		case Opt_noload:
+			set_opt (sbi->s_mount_opt, NOLOAD);
+			break;
+		case Opt_commit:
+			sbi->s_commit_interval = HZ * match_int(&args[0]);
+			break;
+		case Opt_data_journal:
+			data_opt = EXT3_MOUNT_JOURNAL_DATA;
+			goto datacheck;
+		case Opt_data_ordered:
+			data_opt = EXT3_MOUNT_ORDERED_DATA;
+			goto datacheck;
+		case Opt_data_writeback:
+			data_opt = EXT3_MOUNT_WRITEBACK_DATA;
+		datacheck:
+			if (is_remount) {
+				if ((sbi->s_mount_opt & EXT3_MOUNT_DATA_FLAGS)
+						!= data_opt) {
+					printk(KERN_ERR
+						"EXT3-fs: cannot change data "
+						"mode on remount\n");
 					return 0;
 				}
-				*inum = match_int(&args[0]);
-				break;
-			case Opt_noload:
-				set_opt (sbi->s_mount_opt, NOLOAD);
-				break;
-			case Opt_commit:
-				sbi->s_commit_interval = HZ * match_int(&args[0]);
-				break;
-			case Opt_data_journal:
-				data_opt = EXT3_MOUNT_JOURNAL_DATA;
-				goto datacheck;
-			case Opt_data_ordered:
-				data_opt = EXT3_MOUNT_ORDERED_DATA;
-				goto datacheck;
-			case Opt_data_writeback:
-				data_opt = EXT3_MOUNT_WRITEBACK_DATA;
-			datacheck:
-				if (is_remount) {
-					if ((sbi->s_mount_opt & EXT3_MOUNT_DATA_FLAGS)
-							!= data_opt) {
-						printk(KERN_ERR
-							"EXT3-fs: cannot change data "
-							"mode on remount\n");
-						return 0;
-					}
-				} else {
-					sbi->s_mount_opt &= ~EXT3_MOUNT_DATA_FLAGS;
-					sbi->s_mount_opt |= data_opt;
-				}
-				break;
-			case Opt_abort:
-				set_opt (sbi->s_mount_opt, ABORT);
-				break;
-			case Opt_ignore:
-				break;
-			default:
-				printk (KERN_ERR
-					"EXT3-fs: Unrecognized mount option \"%s\" "
-					"or missing value\n", p);
-				return 0;
+			} else {
+				sbi->s_mount_opt &= ~EXT3_MOUNT_DATA_FLAGS;
+				sbi->s_mount_opt |= data_opt;
+			}
+			break;
+		case Opt_abort:
+			set_opt (sbi->s_mount_opt, ABORT);
+			break;
+		case Opt_ignore:
+			break;
+		default:
+			printk (KERN_ERR
+				"EXT3-fs: Unrecognized mount option \"%s\" "
+				"or missing value\n", p);
+			return 0;
 		}
 	}
 
diff -puN fs/fat/inode.c~filesystem-option-parsing-tweaks fs/fat/inode.c
--- 25/fs/fat/inode.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/fat/inode.c	2003-09-26 22:20:16.000000000 -0700
@@ -363,195 +363,195 @@ static int parse_options(char *options, 
 
 		token = match_token(p, FAT_tokens, args);
 		switch (token) {
-			case Opt_check_s:
-				opts->name_check = 's';
-				break;
-			case Opt_check_r:
+		case Opt_check_s:
+			opts->name_check = 's';
+			break;
+		case Opt_check_r:
  				opts->name_check = 'r';
-				break;
-			case Opt_check_n:
+			break;
+		case Opt_check_n:
  				opts->name_check = 'n';
-				break;
-			case Opt_dots:		/* msdos specific */
-				if (!is_vfat)
-					opts->dotsOK = 1;
-				break;
-			case Opt_nodots:	/* msdos specific */
-				if (!is_vfat)
-					opts->dotsOK = 0;
-				break;
-			case Opt_nocase:
-				if (!is_vfat)
-					opts->nocase = 1;
-				else {
-					/* for backward compatibility */
-					opts->shortname = VFAT_SFN_DISPLAY_WIN95
-						| VFAT_SFN_CREATE_WIN95;
-				}
-				break;
-			case Opt_quiet:
-				opts->quiet = 1;
-				break;
-			case Opt_showexec:
-				opts->showexec = 1;
-				break;
-			case Opt_debug:
-				*debug = 1;
-				break;
-			case Opt_immutable:
-				opts->sys_immutable = 1;
-				break;
-			case Opt_uid:
-			{
-				int uid = match_int(&args[0]);
-				if (!uid)
-					return 0;
-				opts->fs_uid = uid;
-				break;
+			break;
+		case Opt_dots:		/* msdos specific */
+			if (!is_vfat)
+				opts->dotsOK = 1;
+			break;
+		case Opt_nodots:	/* msdos specific */
+			if (!is_vfat)
+				opts->dotsOK = 0;
+			break;
+		case Opt_nocase:
+			if (!is_vfat)
+				opts->nocase = 1;
+			else {
+				/* for backward compatibility */
+				opts->shortname = VFAT_SFN_DISPLAY_WIN95
+					| VFAT_SFN_CREATE_WIN95;
 			}
-			case Opt_gid:
-			{
-				int gid = match_int(&args[0]);
-				if (!gid)
+			break;
+		case Opt_quiet:
+			opts->quiet = 1;
+			break;
+		case Opt_showexec:
+			opts->showexec = 1;
+			break;
+		case Opt_debug:
+			*debug = 1;
+			break;
+		case Opt_immutable:
+			opts->sys_immutable = 1;
+			break;
+		case Opt_uid:
+		{
+			int uid = match_int(&args[0]);
+			if (!uid)
+				return 0;
+			opts->fs_uid = uid;
+			break;
+		}
+		case Opt_gid:
+		{
+			int gid = match_int(&args[0]);
+			if (!gid)
+				return 0;
+			opts->fs_gid = gid;
+			break;
+		}
+		case Opt_umask:
+		{
+			int mask = match_octal(&args[0]);
+			if (!mask)
+				return 0;
+			opts->fs_fmask = opts->fs_dmask = mask;
+			break;
+		}
+		case Opt_dmask:
+		{
+			int mask = match_octal(&args[0]);
+			if (!mask)
+				return 0;
+			opts->fs_dmask = mask;
+			break;
+		}
+		case Opt_fmask:
+		{
+			int mask = match_octal(&args[0]);
+			if (!mask)
+				return 0;
+			opts->fs_fmask = mask;
+			break;
+		}
+		case Opt_codepage:
+			opts->codepage = match_int(&args[0]);
+			printk("MSDOS FS: Using codepage %d\n",
+ 					opts->codepage);
+			break;
+
+		/* vfat specific */
+		case Opt_charset:
+			if (is_vfat) {
+				kfree(opts->iocharset);
+				opts->iocharset = match_strdup(&args[0]);
+				if (!opts->iocharset)
 					return 0;
-				opts->fs_gid = gid;
-				break;
+				printk("MSDOS FS: IO charset %s\n",
+					opts->iocharset);
 			}
-			case Opt_umask:
-			{
-				int mask = match_octal(&args[0]);
-				if (!mask)
-					return 0;
-				opts->fs_fmask = opts->fs_dmask = mask;
-				break;
+			break;
+		case Opt_shortname_lower:
+			if (is_vfat) {
+				opts->shortname = VFAT_SFN_DISPLAY_LOWER
+						| VFAT_SFN_CREATE_WIN95;
 			}
-			case Opt_dmask:
-			{
-				int mask = match_octal(&args[0]);
-				if (!mask)
-					return 0;
-				opts->fs_dmask = mask;
-				break;
+			break;
+		case Opt_shortname_win95:
+			if (is_vfat) {
+				opts->shortname = VFAT_SFN_DISPLAY_WIN95
+						| VFAT_SFN_CREATE_WIN95;
 			}
-			case Opt_fmask:
-			{
-				int mask = match_octal(&args[0]);
-				if (!mask)
-					return 0;
-				opts->fs_fmask = mask;
-				break;
+			break;
+		case Opt_shortname_winnt:
+			if (is_vfat) {
+				opts->shortname = VFAT_SFN_DISPLAY_WINNT
+						| VFAT_SFN_CREATE_WINNT;
 			}
-			case Opt_codepage:
-				opts->codepage = match_int(&args[0]);
-				printk("MSDOS FS: Using codepage %d\n",
- 					opts->codepage);
-				break;
+			break;
+		case Opt_shortname_mixed:
+			if (is_vfat) {
+				opts->shortname = VFAT_SFN_DISPLAY_WINNT
+						| VFAT_SFN_CREATE_WIN95;
+			}
+			break;
+		case Opt_utf8_off:	/* 0 or no or false */
+		case Opt_utf8_no:
+		case Opt_utf8_false:
+			if (is_vfat) {
+				opts->utf8 = 0;
+			}
+			break;
+		case Opt_utf8_on:	/* empty or 1 or yes or true */
+		case Opt_utf8_opt:
+		case Opt_utf8_yes:
+		case Opt_utf8_true:
+			if (is_vfat) {
+				opts->utf8 = 1;
+			}
+			break;
+		case Opt_uni_xl_off:	/* 0 or no or false */
+		case Opt_uni_xl_no:
+		case Opt_uni_xl_false:
+			if (is_vfat) {
+				opts->unicode_xlate = 0;
+			}
+			break;
+		case Opt_uni_xl_on:	/* empty or 1 or yes or true */
+		case Opt_uni_xl_yes:
+		case Opt_uni_xl_true:
+		case Opt_uni_xl_opt:
+			if (is_vfat) {
+				opts->unicode_xlate = 1;
+			}
+			break;
+		case Opt_nonumtail_off:		/* 0 or no or false */
+		case Opt_nonumtail_no:
+		case Opt_nonumtail_false:
+			if (is_vfat) {
+					opts->numtail = 1;	/* negated option */
+			}
+			break;
+		case Opt_nonumtail_on:		/* empty or 1 or yes or true */
+		case Opt_nonumtail_yes:
+		case Opt_nonumtail_true:
+		case Opt_nonumtail_opt:
+			if (is_vfat) {
+					opts->numtail = 0;	/* negated option */
+			}
+			break;
 
-			/* vfat specific */
-			case Opt_charset:
-				if (is_vfat) {
-					kfree(opts->iocharset);
-					opts->iocharset = match_strdup(&args[0]);
-					if (!opts->iocharset)
-						return 0;
-					printk("MSDOS FS: IO charset %s\n",
-						opts->iocharset);
-				}
-				break;
-			case Opt_shortname_lower:
-				if (is_vfat) {
-					opts->shortname = VFAT_SFN_DISPLAY_LOWER
-							| VFAT_SFN_CREATE_WIN95;
-				}
-				break;
-			case Opt_shortname_win95:
-				if (is_vfat) {
-					opts->shortname = VFAT_SFN_DISPLAY_WIN95
-							| VFAT_SFN_CREATE_WIN95;
-				}
-				break;
-			case Opt_shortname_winnt:
-				if (is_vfat) {
-					opts->shortname = VFAT_SFN_DISPLAY_WINNT
-							| VFAT_SFN_CREATE_WINNT;
-				}
-				break;
-			case Opt_shortname_mixed:
-				if (is_vfat) {
-					opts->shortname = VFAT_SFN_DISPLAY_WINNT
-							| VFAT_SFN_CREATE_WIN95;
-				}
-				break;
-			case Opt_utf8_off:	/* 0 or no or false */
-			case Opt_utf8_no:
-			case Opt_utf8_false:
-				if (is_vfat) {
-					opts->utf8 = 0;
-				}
-				break;
-			case Opt_utf8_on:	/* empty or 1 or yes or true */
-			case Opt_utf8_opt:
-			case Opt_utf8_yes:
-			case Opt_utf8_true:
-				if (is_vfat) {
-					opts->utf8 = 1;
-				}
-				break;
-			case Opt_uni_xl_off:	/* 0 or no or false */
-			case Opt_uni_xl_no:
-			case Opt_uni_xl_false:
-				if (is_vfat) {
-					opts->unicode_xlate = 0;
-				}
-				break;
-			case Opt_uni_xl_on:	/* empty or 1 or yes or true */
-			case Opt_uni_xl_yes:
-			case Opt_uni_xl_true:
-			case Opt_uni_xl_opt:
-				if (is_vfat) {
-					opts->unicode_xlate = 1;
-				}
-				break;
-			case Opt_nonumtail_off:		/* 0 or no or false */
-			case Opt_nonumtail_no:
-			case Opt_nonumtail_false:
-				if (is_vfat) {
-						opts->numtail = 1;	/* negated option */
-				}
-				break;
-			case Opt_nonumtail_on:		/* empty or 1 or yes or true */
-			case Opt_nonumtail_yes:
-			case Opt_nonumtail_true:
-			case Opt_nonumtail_opt:
-				if (is_vfat) {
-						opts->numtail = 0;	/* negated option */
-				}
-				break;
-
-			/* obsolete mount options */
-			case Opt_conv_b:
-			case Opt_conv_t:
-			case Opt_conv_a:
-				print_obsolete_option("conv");
-				break;
-			case Opt_blocksize:
-				print_obsolete_option("blocksize");
-				break;
-			case Opt_posix:
-				print_obsolete_option("posix");
-				break;
-			case Opt_fat:
-				print_obsolete_option("fat");
-				break;
-			case Opt_cvf_format:
-			case Opt_cvf_options:
-				print_obsolete_option("cvf");
-				break;
-			/* unknown option */
-			default:
-				printk(KERN_ERR "FAT: Unrecognized mount option \"%s\" "
-						"or missing value\n", p);
-				return 0;
+		/* obsolete mount options */
+		case Opt_conv_b:
+		case Opt_conv_t:
+		case Opt_conv_a:
+			print_obsolete_option("conv");
+			break;
+		case Opt_blocksize:
+			print_obsolete_option("blocksize");
+			break;
+		case Opt_posix:
+			print_obsolete_option("posix");
+			break;
+		case Opt_fat:
+			print_obsolete_option("fat");
+			break;
+		case Opt_cvf_format:
+		case Opt_cvf_options:
+			print_obsolete_option("cvf");
+			break;
+		/* unknown option */
+		default:
+			printk(KERN_ERR "FAT: Unrecognized mount option \"%s\" "
+					"or missing value\n", p);
+			return 0;
 		}
 	}
 
diff -puN fs/hfs/super.c~filesystem-option-parsing-tweaks fs/hfs/super.c
--- 25/fs/hfs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/hfs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -306,93 +306,93 @@ static int parse_options(char *options, 
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			/* Numeric-valued options */
-			case Opt_version:
-				hsb->s_version = match_int(&args[0]);
-				break;
-			case Opt_uid:
-				hsb->s_uid = match_int(&args[0]);
-				break;
-			case Opt_gid:
-				hsb->s_gid = match_int(&args[0]);
-				break;
-			case Opt_umask:
-				hsb->s_umask = match_octal(&args[0]);
-				break;
-			case Opt_part:
-				*part = match_int(&args[0]);
-				break;
-			/* String-valued options */
-			case Opt_type:
-				if (strlen(args[0].from) != 4) {
-					return 0;
-				}
-				hsb->s_type = hfs_get_nl(args[0].from);
-				break;
-			case Opt_creator:
-				if (strlen(args[0].from) != 4) {
-					return 0;
-				}
-				hsb->s_creator = hfs_get_nl(args[0].from);
-				break;
-			/* Boolean-valued options */
-			case Opt_quiet:
-				hsb->s_quiet = 1;
-				break;
-			case Opt_afpd:
-				hsb->s_afpd = 1;
-				break;
-			/* Multiple choice options */
-			case Opt_names_netatalk:
-				names = 'n';
-				break;
-			case Opt_names_trivial:
-				names = 't';
-				break;
-			case Opt_names_alpha:
-				names = 'a';
-				break;
-			case Opt_names_latin:
-				names = 'l';
-				break;
-			case Opt_names_7bit:
-				names = '7';
-				break;
-			case Opt_names_8bit:
-				names = '8';
-				break;
-			case Opt_names_cap:
-				names = 'c';
-				break;
-			case Opt_fork_netatalk:
-				fork = 'n';
-				break;
-			case Opt_fork_single:
-				fork = 's';
-				break;
-			case Opt_fork_double:
-				fork = 'd';
-				break;
-			case Opt_fork_cap:
-				fork = 'c';
-				break;
-			case Opt_case_lower:
-				hsb->s_lowercase = 1;
-				break;
-			case Opt_case_asis:
-				hsb->s_lowercase = 0;
-				break;
-			case Opt_conv_binary:
-				hsb->s_conv = 'b';
-				break;
-			case Opt_conv_text:
-				hsb->s_conv = 't';
-				break;
-			case Opt_conv_auto:
-				hsb->s_conv = 'a';
-				break;
-			default:
+		/* Numeric-valued options */
+		case Opt_version:
+			hsb->s_version = match_int(&args[0]);
+			break;
+		case Opt_uid:
+			hsb->s_uid = match_int(&args[0]);
+			break;
+		case Opt_gid:
+			hsb->s_gid = match_int(&args[0]);
+			break;
+		case Opt_umask:
+			hsb->s_umask = match_octal(&args[0]);
+			break;
+		case Opt_part:
+			*part = match_int(&args[0]);
+			break;
+		/* String-valued options */
+		case Opt_type:
+			if (strlen(args[0].from) != 4) {
 				return 0;
+			}
+			hsb->s_type = hfs_get_nl(args[0].from);
+			break;
+		case Opt_creator:
+			if (strlen(args[0].from) != 4) {
+				return 0;
+			}
+			hsb->s_creator = hfs_get_nl(args[0].from);
+			break;
+		/* Boolean-valued options */
+		case Opt_quiet:
+			hsb->s_quiet = 1;
+			break;
+		case Opt_afpd:
+			hsb->s_afpd = 1;
+			break;
+		/* Multiple choice options */
+		case Opt_names_netatalk:
+			names = 'n';
+			break;
+		case Opt_names_trivial:
+			names = 't';
+			break;
+		case Opt_names_alpha:
+			names = 'a';
+			break;
+		case Opt_names_latin:
+			names = 'l';
+			break;
+		case Opt_names_7bit:
+			names = '7';
+			break;
+		case Opt_names_8bit:
+			names = '8';
+			break;
+		case Opt_names_cap:
+			names = 'c';
+			break;
+		case Opt_fork_netatalk:
+			fork = 'n';
+			break;
+		case Opt_fork_single:
+			fork = 's';
+			break;
+		case Opt_fork_double:
+			fork = 'd';
+			break;
+		case Opt_fork_cap:
+			fork = 'c';
+			break;
+		case Opt_case_lower:
+			hsb->s_lowercase = 1;
+			break;
+		case Opt_case_asis:
+			hsb->s_lowercase = 0;
+			break;
+		case Opt_conv_binary:
+			hsb->s_conv = 'b';
+			break;
+		case Opt_conv_text:
+			hsb->s_conv = 't';
+			break;
+		case Opt_conv_auto:
+			hsb->s_conv = 'a';
+			break;
+		default:
+			return 0;
 		}
 	}
 
diff -puN fs/hpfs/super.c~filesystem-option-parsing-tweaks fs/hpfs/super.c
--- 25/fs/hpfs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/hpfs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -279,83 +279,83 @@ int parse_opts(char *opts, uid_t *uid, g
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_help:
-				return 2;
-			case Opt_uid:
-				*uid = match_int(args);
-				break;
-			case Opt_gid:
-				*gid = match_int(args);
-				break;
-			case Opt_umask:
-				*umask = match_octal(args);
-				break;
-			case Opt_case_lower:
-				*lowercase = 1;
-				break;
-			case Opt_case_asis:
-				*lowercase = 0;
-				break;
-			case Opt_conv_binary:
-				*conv = CONV_BINARY;
-				break;
-			case Opt_conv_text:
-				*conv = CONV_TEXT;
-				break;
-			case Opt_conv_auto:
-				*conv = CONV_AUTO;
-				break;
-			case Opt_check_none:
-				*chk = 0;
-				break;
-			case Opt_check_normal:
-				*chk = 1;
-				break;
-			case Opt_check_strict:
-				*chk = 2;
-				break;
-			case Opt_err_cont:
-				*errs = 0;
-				break;
-			case Opt_err_ro:
-				*errs = 1;
-				break;
-			case Opt_err_panic:
-				*errs = 2;
-				break;
-			case Opt_eas_no:
-				*eas = 0;
-				break;
-			case Opt_eas_ro:
-				*eas = 1;
-				break;
-			case Opt_eas_rw:
-				*eas = 2;
-				break;
-			case Opt_chkdsk_no:
-				*chkdsk = 0;
-				break;
-			case Opt_chkdsk_errors:
-				*chkdsk = 1;
-				break;
-			case Opt_chkdsk_always:
-				*chkdsk = 2;
-				break;
-			case Opt_timeshift:
-			{
-				int m = 1;
-				char *rhs = args[0].from;
-				if (!rhs || !*rhs)
-					return 0;
-				if (*rhs == '-') m = -1;
-				if (*rhs == '+' || *rhs == '-') rhs++;
-				*timeshift = simple_strtoul(rhs, &rhs, 0) * m;
-				if (*rhs)
-					return 0;
-				break;
-			}
-			default:
+		case Opt_help:
+			return 2;
+		case Opt_uid:
+			*uid = match_int(args);
+			break;
+		case Opt_gid:
+			*gid = match_int(args);
+			break;
+		case Opt_umask:
+			*umask = match_octal(args);
+			break;
+		case Opt_case_lower:
+			*lowercase = 1;
+			break;
+		case Opt_case_asis:
+			*lowercase = 0;
+			break;
+		case Opt_conv_binary:
+			*conv = CONV_BINARY;
+			break;
+		case Opt_conv_text:
+			*conv = CONV_TEXT;
+			break;
+		case Opt_conv_auto:
+			*conv = CONV_AUTO;
+			break;
+		case Opt_check_none:
+			*chk = 0;
+			break;
+		case Opt_check_normal:
+			*chk = 1;
+			break;
+		case Opt_check_strict:
+			*chk = 2;
+			break;
+		case Opt_err_cont:
+			*errs = 0;
+			break;
+		case Opt_err_ro:
+			*errs = 1;
+			break;
+		case Opt_err_panic:
+			*errs = 2;
+			break;
+		case Opt_eas_no:
+			*eas = 0;
+			break;
+		case Opt_eas_ro:
+			*eas = 1;
+			break;
+		case Opt_eas_rw:
+			*eas = 2;
+			break;
+		case Opt_chkdsk_no:
+			*chkdsk = 0;
+			break;
+		case Opt_chkdsk_errors:
+			*chkdsk = 1;
+			break;
+		case Opt_chkdsk_always:
+			*chkdsk = 2;
+			break;
+		case Opt_timeshift:
+		{
+			int m = 1;
+			char *rhs = args[0].from;
+			if (!rhs || !*rhs)
 				return 0;
+			if (*rhs == '-') m = -1;
+			if (*rhs == '+' || *rhs == '-') rhs++;
+			*timeshift = simple_strtoul(rhs, &rhs, 0) * m;
+			if (*rhs)
+				return 0;
+			break;
+		}
+		default:
+			return 0;
 		}
 	}
 	return 1;
diff -puN fs/isofs/inode.c~filesystem-option-parsing-tweaks fs/isofs/inode.c
--- 25/fs/isofs/inode.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/isofs/inode.c	2003-09-26 22:20:16.000000000 -0700
@@ -406,75 +406,75 @@ static int parse_options(char *options, 
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_norock:
-				popt->rock = 'n';
-				break;
-			case Opt_nojoliet:
-				popt->joliet = 'n';
-				break;
-			case Opt_unhide:
-				popt->unhide = 'y';
-				break;
-			case Opt_cruft:
-				popt->cruft = 'y';
-				break;
-			case Opt_utf8:
-				popt->utf8 = 1;
-				break;
+		case Opt_norock:
+			popt->rock = 'n';
+			break;
+		case Opt_nojoliet:
+			popt->joliet = 'n';
+			break;
+		case Opt_unhide:
+			popt->unhide = 'y';
+			break;
+		case Opt_cruft:
+			popt->cruft = 'y';
+			break;
+		case Opt_utf8:
+			popt->utf8 = 1;
+			break;
 #ifdef CONFIG_JOLIET
-			case Opt_iocharset:
-				popt->iocharset = match_strdup(&args[0]);
-				break;
+		case Opt_iocharset:
+			popt->iocharset = match_strdup(&args[0]);
+			break;
 #endif
-			case Opt_map_a:
-				popt->map = 'a';
-				break;
-			case Opt_map_o:
-				popt->map = 'o';
-				break;
-			case Opt_map_n:
-				popt->map = 'n';
-				break;
-			case Opt_session:
-				n = match_int(&args[0]);
-				if (n > 99)
-					return 0;
-				popt->session = n + 1;
-				break;
-			case Opt_sb:
-				n = match_int(&args[0]);
-				if (n > 660 * 512)
-					return 0;
-				popt->sbsector = n;
-				break;
-			case Opt_check_r:
-				popt->check = 'r';
-				break;
-			case Opt_check_s:
-				popt->check = 's';
-				break;
-			case Opt_ignore:
-				break;
-			case Opt_uid:
-				popt->uid = match_int(&args[0]);
-				break;
-			case Opt_gid:
-				popt->gid = match_int(&args[0]);
-				break;
-			case Opt_mode:
-				popt->mode = match_int(&args[0]);
-				break;
-			case Opt_block:
-				n = match_int(&args[0]);
-				if (n != 512 && n != 1024 && n != 2048)
-					return 0;
-				popt->blocksize = n;
-				break;
-			case Opt_nocompress:
-				popt->nocompress = 1;
-				break;
-			default:
+		case Opt_map_a:
+			popt->map = 'a';
+			break;
+		case Opt_map_o:
+			popt->map = 'o';
+			break;
+		case Opt_map_n:
+			popt->map = 'n';
+			break;
+		case Opt_session:
+			n = match_int(&args[0]);
+			if (n > 99)
+				return 0;
+			popt->session = n + 1;
+			break;
+		case Opt_sb:
+			n = match_int(&args[0]);
+			if (n > 660 * 512)
+				return 0;
+			popt->sbsector = n;
+			break;
+		case Opt_check_r:
+			popt->check = 'r';
+			break;
+		case Opt_check_s:
+			popt->check = 's';
+			break;
+		case Opt_ignore:
+			break;
+		case Opt_uid:
+			popt->uid = match_int(&args[0]);
+			break;
+		case Opt_gid:
+			popt->gid = match_int(&args[0]);
+			break;
+		case Opt_mode:
+			popt->mode = match_int(&args[0]);
+			break;
+		case Opt_block:
+			n = match_int(&args[0]);
+			if (n != 512 && n != 1024 && n != 2048)
 				return 0;
+			popt->blocksize = n;
+			break;
+		case Opt_nocompress:
+			popt->nocompress = 1;
+			break;
+		default:
+			return 0;
 		}
 	}
 	return 1;
diff -puN fs/jfs/super.c~filesystem-option-parsing-tweaks fs/jfs/super.c
--- 25/fs/jfs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/jfs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -202,42 +202,42 @@ static int parse_options(char *options, 
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_integrity:
-				*flag &= ~JFS_NOINTEGRITY;
-				break;
-			case Opt_nointegrity:
-				*flag |= JFS_NOINTEGRITY;
-				break;
-			case Opt_ignore:
-				/* Silently ignore the quota options */
-				/* Don't do anything ;-) */
-				break;
-			case Opt_iocharset:
-				if (nls_map)	/* specified iocharset twice! */
-					unload_nls(nls_map);
-				nls_map = load_nls(args[0].from);
-				if (!nls_map) {
-					printk(KERN_ERR "JFS: charset not found\n");
-					goto cleanup;
-				}
-				break;
-			case Opt_resize:
-			{
-				char *resize = args[0].from;
-				if (!resize || !*resize) {
-					*newLVSize = sb->s_bdev->bd_inode->i_size >>
-						sb->s_blocksize_bits;
-					if (*newLVSize == 0)
-						printk(KERN_ERR
-						"JFS: Cannot determine volume size\n");
-				} else
-					*newLVSize = simple_strtoull(resize, &resize, 0);
-				break;
-			}
-			default:
-				printk("jfs: Unrecognized mount option \"%s\" "
-						" or missing value\n", p);
+		case Opt_integrity:
+			*flag &= ~JFS_NOINTEGRITY;
+			break;
+		case Opt_nointegrity:
+			*flag |= JFS_NOINTEGRITY;
+			break;
+		case Opt_ignore:
+			/* Silently ignore the quota options */
+			/* Don't do anything ;-) */
+			break;
+		case Opt_iocharset:
+			if (nls_map)	/* specified iocharset twice! */
+				unload_nls(nls_map);
+			nls_map = load_nls(args[0].from);
+			if (!nls_map) {
+				printk(KERN_ERR "JFS: charset not found\n");
 				goto cleanup;
+			}
+			break;
+		case Opt_resize:
+		{
+			char *resize = args[0].from;
+			if (!resize || !*resize) {
+				*newLVSize = sb->s_bdev->bd_inode->i_size >>
+					sb->s_blocksize_bits;
+				if (*newLVSize == 0)
+					printk(KERN_ERR
+					"JFS: Cannot determine volume size\n");
+			} else
+				*newLVSize = simple_strtoull(resize, &resize, 0);
+			break;
+		}
+		default:
+			printk("jfs: Unrecognized mount option \"%s\" "
+					" or missing value\n", p);
+			goto cleanup;
 		}
 	}
 
diff -puN fs/proc/inode.c~filesystem-option-parsing-tweaks fs/proc/inode.c
--- 25/fs/proc/inode.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/proc/inode.c	2003-09-26 22:20:16.000000000 -0700
@@ -163,14 +163,14 @@ static int parse_options(char *options,u
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_uid:
-				*uid = match_int(args);
-				break;
-			case Opt_gid:
-				*gid = match_int(args);
-				break;
-			default:
-				return 0;
+		case Opt_uid:
+			*uid = match_int(args);
+			break;
+		case Opt_gid:
+			*gid = match_int(args);
+			break;
+		default:
+			return 0;
 		}
 	}
 	return 1;
diff -puN fs/udf/super.c~filesystem-option-parsing-tweaks fs/udf/super.c
--- 25/fs/udf/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/udf/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -329,77 +329,77 @@ udf_parse_options(char *options, struct 
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_novrs:
-				uopt->novrs = 1;
-				break;
-			case Opt_bs:
-				uopt->blocksize = match_int(&args[0]);
-				break;
-			case Opt_unhide:
-				uopt->flags |= (1 << UDF_FLAG_UNHIDE);
-				break;
-			case Opt_undelete:
-				uopt->flags |= (1 << UDF_FLAG_UNDELETE);
-				break;
-			case Opt_noadinicb:
-				uopt->flags &= ~(1 << UDF_FLAG_USE_AD_IN_ICB);
-				break;
-			case Opt_adinicb:
-				uopt->flags |= (1 << UDF_FLAG_USE_AD_IN_ICB);
-				break;
-			case Opt_shortad:
-				uopt->flags |= (1 << UDF_FLAG_USE_SHORT_AD);
-				break;
-			case Opt_longad:
-				uopt->flags &= ~(1 << UDF_FLAG_USE_SHORT_AD);
-				break;
-			case Opt_gid:
-				uopt->gid = match_int(args);
-				break;
-			case Opt_uid:
-				uopt->uid = match_int(args);
-				break;
-			case Opt_umask:
-				uopt->umask = match_octal(args);
-				break;
-			case Opt_nostrict:
-				uopt->flags &= ~(1 << UDF_FLAG_STRICT);
-				break;
-			case Opt_session:
-				uopt->session = match_int(args);
-				break;
-			case Opt_lastblock:
-				uopt->lastblock = match_int(args);
-				break;
-			case Opt_anchor:
-				uopt->anchor = match_int(args);
-				break;
-			case Opt_volume:
-				uopt->volume = match_int(args);
-				break;
-			case Opt_partition:
-				uopt->partition = match_int(args);
-				break;
-			case Opt_fileset:
-				uopt->fileset = match_int(args);
-				break;
-			case Opt_rootdir:
-				uopt->rootdir = match_int(args);
-				break;
-			case Opt_utf8:
-				uopt->flags |= (1 << UDF_FLAG_UTF8);
-				break;
+		case Opt_novrs:
+			uopt->novrs = 1;
+			break;
+		case Opt_bs:
+			uopt->blocksize = match_int(&args[0]);
+			break;
+		case Opt_unhide:
+			uopt->flags |= (1 << UDF_FLAG_UNHIDE);
+			break;
+		case Opt_undelete:
+			uopt->flags |= (1 << UDF_FLAG_UNDELETE);
+			break;
+		case Opt_noadinicb:
+			uopt->flags &= ~(1 << UDF_FLAG_USE_AD_IN_ICB);
+			break;
+		case Opt_adinicb:
+			uopt->flags |= (1 << UDF_FLAG_USE_AD_IN_ICB);
+			break;
+		case Opt_shortad:
+			uopt->flags |= (1 << UDF_FLAG_USE_SHORT_AD);
+			break;
+		case Opt_longad:
+			uopt->flags &= ~(1 << UDF_FLAG_USE_SHORT_AD);
+			break;
+		case Opt_gid:
+			uopt->gid = match_int(args);
+			break;
+		case Opt_uid:
+			uopt->uid = match_int(args);
+			break;
+		case Opt_umask:
+			uopt->umask = match_octal(args);
+			break;
+		case Opt_nostrict:
+			uopt->flags &= ~(1 << UDF_FLAG_STRICT);
+			break;
+		case Opt_session:
+			uopt->session = match_int(args);
+			break;
+		case Opt_lastblock:
+			uopt->lastblock = match_int(args);
+			break;
+		case Opt_anchor:
+			uopt->anchor = match_int(args);
+			break;
+		case Opt_volume:
+			uopt->volume = match_int(args);
+			break;
+		case Opt_partition:
+			uopt->partition = match_int(args);
+			break;
+		case Opt_fileset:
+			uopt->fileset = match_int(args);
+			break;
+		case Opt_rootdir:
+			uopt->rootdir = match_int(args);
+			break;
+		case Opt_utf8:
+			uopt->flags |= (1 << UDF_FLAG_UTF8);
+			break;
 #ifdef CONFIG_NLS
-			case Opt_iocharset:
-				uopt->nls_map = load_nls(args[0].from);
-				uopt->flags |= (1 << UDF_FLAG_NLS_MAP);
-				break;
+		case Opt_iocharset:
+			uopt->nls_map = load_nls(args[0].from);
+			uopt->flags |= (1 << UDF_FLAG_NLS_MAP);
+			break;
 #endif
-			default:
-				printk(KERN_ERR "udf: bad mount option \"%s\" "
-						"or missing value\n",
-					p);
-				return 0;
+		default:
+			printk(KERN_ERR "udf: bad mount option \"%s\" "
+					"or missing value\n",
+				p);
+			return 0;
 		}
 	}
 	return 1;
diff -puN fs/ufs/super.c~filesystem-option-parsing-tweaks fs/ufs/super.c
--- 25/fs/ufs/super.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/fs/ufs/super.c	2003-09-26 22:20:16.000000000 -0700
@@ -291,60 +291,60 @@ static int ufs_parse_options (char * opt
 
 		token = match_token(p, tokens, args);
 		switch (token) {
-			case Opt_type_old:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_OLD);
-				break;
-			case Opt_type_sunx86:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_SUNx86);
-				break;
-			case Opt_type_sun:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_SUN);
-				break;
-			case Opt_type_44bsd:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_44BSD);
-				break;
-			case Opt_type_hp:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_HP);
-				break;
-			case Opt_type_nextstepcd:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_NEXTSTEP_CD);
-				break;
-			case Opt_type_nextstep:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_NEXTSTEP);
-				break;
-			case Opt_type_openstep:
-				ufs_clear_opt (*mount_options, UFSTYPE);
-				ufs_set_opt (*mount_options, UFSTYPE_OPENSTEP);
-				break;
-			case Opt_onerror_panic:
-				ufs_clear_opt (*mount_options, ONERROR);
-				ufs_set_opt (*mount_options, ONERROR_PANIC);
-				break;
-			case Opt_onerror_lock:
-				ufs_clear_opt (*mount_options, ONERROR);
-				ufs_set_opt (*mount_options, ONERROR_LOCK);
-				break;
-			case Opt_onerror_umount:
-				ufs_clear_opt (*mount_options, ONERROR);
-				ufs_set_opt (*mount_options, ONERROR_UMOUNT);
-				break;
-			case Opt_onerror_repair:
-				printk("UFS-fs: Unable to do repair on error, "
-					"will lock lock instead\n");
-				ufs_clear_opt (*mount_options, ONERROR);
-				ufs_set_opt (*mount_options, ONERROR_REPAIR);
-				break;
-			default:
-				printk("UFS-fs: Invalid option: \"%s\" "
-						"or missing value\n", p);
-				return 0;
+		case Opt_type_old:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_OLD);
+			break;
+		case Opt_type_sunx86:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_SUNx86);
+			break;
+		case Opt_type_sun:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_SUN);
+			break;
+		case Opt_type_44bsd:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_44BSD);
+			break;
+		case Opt_type_hp:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_HP);
+			break;
+		case Opt_type_nextstepcd:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_NEXTSTEP_CD);
+			break;
+		case Opt_type_nextstep:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_NEXTSTEP);
+			break;
+		case Opt_type_openstep:
+			ufs_clear_opt (*mount_options, UFSTYPE);
+			ufs_set_opt (*mount_options, UFSTYPE_OPENSTEP);
+			break;
+		case Opt_onerror_panic:
+			ufs_clear_opt (*mount_options, ONERROR);
+			ufs_set_opt (*mount_options, ONERROR_PANIC);
+			break;
+		case Opt_onerror_lock:
+			ufs_clear_opt (*mount_options, ONERROR);
+			ufs_set_opt (*mount_options, ONERROR_LOCK);
+			break;
+		case Opt_onerror_umount:
+			ufs_clear_opt (*mount_options, ONERROR);
+			ufs_set_opt (*mount_options, ONERROR_UMOUNT);
+			break;
+		case Opt_onerror_repair:
+			printk("UFS-fs: Unable to do repair on error, "
+				"will lock lock instead\n");
+			ufs_clear_opt (*mount_options, ONERROR);
+			ufs_set_opt (*mount_options, ONERROR_REPAIR);
+			break;
+		default:
+			printk("UFS-fs: Invalid option: \"%s\" "
+					"or missing value\n", p);
+			return 0;
 		}
 	}
 	return 1;
diff -puN lib/parser.c~filesystem-option-parsing-tweaks lib/parser.c
--- 25/lib/parser.c~filesystem-option-parsing-tweaks	2003-09-26 22:20:16.000000000 -0700
+++ 25-akpm/lib/parser.c	2003-09-26 22:20:16.000000000 -0700
@@ -44,28 +44,28 @@ static int match_one(char *s, char *p, s
 
 		args[argc].from = s;
 		switch (*p++) {
-			case 's':
-				if (len == -1 || len > strlen(s))
-					len = strlen(s);
-				args[argc].to = s + len;
-				break;
-			case 'd':
-				simple_strtol(s, &args[argc].to, 0);
-				goto num;
-			case 'u':
-				simple_strtoul(s, &args[argc].to, 0);
-				goto num;
-			case 'o':
-				simple_strtoul(s, &args[argc].to, 8);
-				goto num;
-			case 'x':
-				simple_strtoul(s, &args[argc].to, 16);
-			num:
-				if (args[argc].to == args[argc].from)
-					return 0;
-				break;
-			default:
+		case 's':
+			if (len == -1 || len > strlen(s))
+				len = strlen(s);
+			args[argc].to = s + len;
+			break;
+		case 'd':
+			simple_strtol(s, &args[argc].to, 0);
+			goto num;
+		case 'u':
+			simple_strtoul(s, &args[argc].to, 0);
+			goto num;
+		case 'o':
+			simple_strtoul(s, &args[argc].to, 8);
+			goto num;
+		case 'x':
+			simple_strtoul(s, &args[argc].to, 16);
+		num:
+			if (args[argc].to == args[argc].from)
 				return 0;
+			break;
+		default:
+			return 0;
 		}
 		s = args[argc].to;
 		argc++;

_
